# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from terrascope_api.models import visualization_pb2 as visualization__pb2


class VisualizationApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.get = channel.unary_unary(
                '/oi.papi.visualization.VisualizationApi/get',
                request_serializer=visualization__pb2.VisualizationGetRequest.SerializeToString,
                response_deserializer=visualization__pb2.VisualizationGetResponse.FromString,
                )
        self.create_config_algo = channel.unary_unary(
                '/oi.papi.visualization.VisualizationApi/create_config_algo',
                request_serializer=visualization__pb2.VisualizerConfigAlgoCreateRequest.SerializeToString,
                response_deserializer=visualization__pb2.VisualizerConfigAlgoCreateResponse.FromString,
                )
        self.get_config_algo = channel.unary_unary(
                '/oi.papi.visualization.VisualizationApi/get_config_algo',
                request_serializer=visualization__pb2.VisualizerConfigAlgoGetRequest.SerializeToString,
                response_deserializer=visualization__pb2.VisualizerConfigAlgoGetResponse.FromString,
                )


class VisualizationApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def get(self, request, context):
        """
        Gets a list of Visualizations that can be used to download visualization data files that can then be rendered on the front end.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def create_config_algo(self, request, context):
        """
        Creates a list of Visualizer Config Algos to fetch Visualizer details for each algorithm_version_id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_config_algo(self, request, context):
        """
        Gets a list of Visualizer Config Algos to fetch Visualizer details for each algorithm_version_id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VisualizationApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=visualization__pb2.VisualizationGetRequest.FromString,
                    response_serializer=visualization__pb2.VisualizationGetResponse.SerializeToString,
            ),
            'create_config_algo': grpc.unary_unary_rpc_method_handler(
                    servicer.create_config_algo,
                    request_deserializer=visualization__pb2.VisualizerConfigAlgoCreateRequest.FromString,
                    response_serializer=visualization__pb2.VisualizerConfigAlgoCreateResponse.SerializeToString,
            ),
            'get_config_algo': grpc.unary_unary_rpc_method_handler(
                    servicer.get_config_algo,
                    request_deserializer=visualization__pb2.VisualizerConfigAlgoGetRequest.FromString,
                    response_serializer=visualization__pb2.VisualizerConfigAlgoGetResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.visualization.VisualizationApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class VisualizationApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.visualization.VisualizationApi/get',
            visualization__pb2.VisualizationGetRequest.SerializeToString,
            visualization__pb2.VisualizationGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def create_config_algo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.visualization.VisualizationApi/create_config_algo',
            visualization__pb2.VisualizerConfigAlgoCreateRequest.SerializeToString,
            visualization__pb2.VisualizerConfigAlgoCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_config_algo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.visualization.VisualizationApi/get_config_algo',
            visualization__pb2.VisualizerConfigAlgoGetRequest.SerializeToString,
            visualization__pb2.VisualizerConfigAlgoGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from terrascope_api.models import toi_pb2 as toi__pb2


class TOIApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/oi.papi.TOIApi/create',
                request_serializer=toi__pb2.TOICreateRequest.SerializeToString,
                response_deserializer=toi__pb2.TOICreateResponse.FromString,
                )
        self.delete = channel.unary_unary(
                '/oi.papi.TOIApi/delete',
                request_serializer=toi__pb2.TOIDeleteRequest.SerializeToString,
                response_deserializer=toi__pb2.TOIDeleteResponse.FromString,
                )
        self.get = channel.unary_unary(
                '/oi.papi.TOIApi/get',
                request_serializer=toi__pb2.TOIGetRequest.SerializeToString,
                response_deserializer=toi__pb2.TOIGetResponse.FromString,
                )
        self.list = channel.unary_unary(
                '/oi.papi.TOIApi/list',
                request_serializer=toi__pb2.TOIListRequest.SerializeToString,
                response_deserializer=toi__pb2.TOIListResponse.FromString,
                )


class TOIApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        Create a new TOI from the given set of TOI metadata. The toi_id for the newly created TOI is returned.
        TOIs that continue past the current date will cause the associated computations to run on a recurring basis until the end date has been reached.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        Deletes the specified TOI, provided that it has not already been used as part of a computation.
        The user must have permission to access the specified TOI.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        Retrieve the TOI for the specified toi_id. The user must have permission to access the specified TOI.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        Retrieves all TOIs that the user has permissions for and that match the provided search filters.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TOIApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=toi__pb2.TOICreateRequest.FromString,
                    response_serializer=toi__pb2.TOICreateResponse.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=toi__pb2.TOIDeleteRequest.FromString,
                    response_serializer=toi__pb2.TOIDeleteResponse.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=toi__pb2.TOIGetRequest.FromString,
                    response_serializer=toi__pb2.TOIGetResponse.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=toi__pb2.TOIListRequest.FromString,
                    response_serializer=toi__pb2.TOIListResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.TOIApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TOIApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.TOIApi/create',
            toi__pb2.TOICreateRequest.SerializeToString,
            toi__pb2.TOICreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.TOIApi/delete',
            toi__pb2.TOIDeleteRequest.SerializeToString,
            toi__pb2.TOIDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.TOIApi/get',
            toi__pb2.TOIGetRequest.SerializeToString,
            toi__pb2.TOIGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oi.papi.TOIApi/list',
            toi__pb2.TOIListRequest.SerializeToString,
            toi__pb2.TOIListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: user.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nuser.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\"/\n\x0cLoginRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"7\n\rLoginResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x11\n\tjwt_token\x18\x02 \x01(\t\"/\n\x04User\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\"L\n\x11UserCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x1a\n\x12user_collection_id\x18\x03 \x01(\t\"F\n\x12UserCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1b\n\x04user\x18\x02 \x01(\x0b\x32\r.oi.papi.User\"\x1d\n\x0eUserGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"D\n\x0fUserGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1c\n\x05users\x18\x02 \x03(\x0b\x32\r.oi.papi.User\" \n\x0fUserListRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"E\n\x10UserListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1c\n\x05users\x18\x02 \x03(\x0b\x32\r.oi.papi.User2\xfb\x01\n\x07UserApi\x12\x36\n\x05login\x12\x15.oi.papi.LoginRequest\x1a\x16.oi.papi.LoginResponse\x12\x41\n\x06\x63reate\x12\x1a.oi.papi.UserCreateRequest\x1a\x1b.oi.papi.UserCreateResponse\x12\x38\n\x03get\x12\x17.oi.papi.UserGetRequest\x1a\x18.oi.papi.UserGetResponse\x12;\n\x04list\x12\x18.oi.papi.UserListRequest\x1a\x19.oi.papi.UserListResponseP\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LOGINREQUEST._serialized_start=44
  _LOGINREQUEST._serialized_end=91
  _LOGINRESPONSE._serialized_start=93
  _LOGINRESPONSE._serialized_end=148
  _USER._serialized_start=150
  _USER._serialized_end=197
  _USERCREATEREQUEST._serialized_start=199
  _USERCREATEREQUEST._serialized_end=275
  _USERCREATERESPONSE._serialized_start=277
  _USERCREATERESPONSE._serialized_end=347
  _USERGETREQUEST._serialized_start=349
  _USERGETREQUEST._serialized_end=378
  _USERGETRESPONSE._serialized_start=380
  _USERGETRESPONSE._serialized_end=448
  _USERLISTREQUEST._serialized_start=450
  _USERLISTREQUEST._serialized_end=482
  _USERLISTRESPONSE._serialized_start=484
  _USERLISTRESPONSE._serialized_end=553
  _USERAPI._serialized_start=556
  _USERAPI._serialized_end=807
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: data_source.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import data_type_pb2 as data__type__pb2

from terrascope_api.models.data_type_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x64\x61ta_source.proto\x12\x07oi.papi\x1a\x0f\x64\x61ta_type.proto\"\xa9\x01\n\nDataSource\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12%\n\ndata_types\x18\x04 \x03(\x0b\x32\x11.oi.papi.DataType\x12\x1c\n\x14\x64\x65livery_lag_seconds\x18\x05 \x01(\x04\x12\x14\n\x0c\x64isplay_name\x18\x06 \x01(\t\x12\x11\n\tindicator\x18\x07 \x01(\t\"#\n\x14\x44\x61taSourceGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"W\n\x15\x44\x61taSourceGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12)\n\x0c\x64\x61ta_sources\x18\x02 \x03(\x0b\x32\x13.oi.papi.DataSource\",\n\x15\x44\x61taSourceListRequest\x12\x13\n\x0bsearch_text\x18\x01 \x01(\t\"X\n\x16\x44\x61taSourceListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12)\n\x0c\x64\x61ta_sources\x18\x02 \x03(\x0b\x32\x13.oi.papi.DataSource2\x9e\x01\n\rDataSourceAPI\x12\x44\n\x03get\x12\x1d.oi.papi.DataSourceGetRequest\x1a\x1e.oi.papi.DataSourceGetResponse\x12G\n\x04list\x12\x1e.oi.papi.DataSourceListRequest\x1a\x1f.oi.papi.DataSourceListResponseP\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'data_source_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DATASOURCE._serialized_start=48
  _DATASOURCE._serialized_end=217
  _DATASOURCEGETREQUEST._serialized_start=219
  _DATASOURCEGETREQUEST._serialized_end=254
  _DATASOURCEGETRESPONSE._serialized_start=256
  _DATASOURCEGETRESPONSE._serialized_end=343
  _DATASOURCELISTREQUEST._serialized_start=345
  _DATASOURCELISTREQUEST._serialized_end=389
  _DATASOURCELISTRESPONSE._serialized_start=391
  _DATASOURCELISTRESPONSE._serialized_end=479
  _DATASOURCEAPI._serialized_start=482
  _DATASOURCEAPI._serialized_end=640
# @@protoc_insertion_point(module_scope)
